/* Copyright 2012 Red Hat, Inc.
 *
 * This software may be freely redistributed under the terms of the GNU
 * public license.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#ifndef _KUDZU_VMBUS_H
#define _KUDZU_VMBUS_H

#include "device.h"
#include "kudzu.h"

/* vmbus device class ids */
#define VMBUS_CLASS_NETWORK	"{f8615163-df3e-46c5-913ff2d2f965ed0e}"
#define VMBUS_CLASS_IDE		"{32412632-86cb-44a2-9b5c50d1417354f5}"
#define VMBUS_CLASS_SCSI	"{ba6163d9-04a1-4d29-b60572e2ffb1dc7f}"
#define VMBUS_CLASS_HID		"{cfa8b69e-5b4a-4cc0-b98b8ba1a1f3f95a}"
#define VMBUS_CLASS_UTIL_1	"{0e0b6031-5213-4934-818b38d90ced39db}"
#define VMBUS_CLASS_UTIL_2	"{9527e630-d0ae-497b-adcee80ab0175caf}"
#define VMBUS_CLASS_UTIL_3	"{57164f39-9115-4e78-ab55382f3bd5422d}"
#define VMBUS_CLASS_UTIL_4	"{a9a0f4e7-5a45-4d96-b8278a841e8c03e6}"
#define VMBUS_CLASS_UNSUPP_1    "{da0a7802-e377-4aac-8e770558eb1073f8}"
#define VMBUS_CLASS_UNSUPP_2	"{35fa2e29-ea23-4236-96ae3a6ebacba440}"

/* vmbus device class descriptions */
#define DESC_VMBUS_NETWORK	"Microsoft Corporation Hyper-V Network Adapter"
#define DESC_VMBUS_IDE		"Microsoft Corporation Hyper-V Storage/IDE"
#define DESC_VMBUS_SCSI		"Microsoft Corporation Hyper-V Storage/SCSI"
#define DESC_VMBUS_HID		"Microsoft Corporation Hyper-V HID/Mouse"
#define DESC_VMBUS_UTIL		"Microsoft Corporation Hyper-V Util"
#define DESC_VMBUS_OTHER	"Microsoft Corporation Hyper-V Other"

struct vmbusDevice {

    /* common fields */
    struct device *next;	/* next device in list */
    int index;
    enum deviceClass type;	/* type */
    enum deviceBus bus;		/* bus it's attached to */
    char * device;		/* device file associated with it */
    char * driver;		/* driver to load, if any */
    char * desc;		/* a description */
    int detached;
    void * classprivate;

    /* vmbus-specific fields */
    struct vmbusDevice *(*newDevice) (struct vmbusDevice *dev);
    void (*freeDevice) (struct vmbusDevice *dev);
    void (*writeDevice) (FILE *file, struct vmbusDevice *dev);
    int (*compareDevice) (struct vmbusDevice *dev1, struct vmbusDevice *dev2);
    char * vmbusclass;
    int devnum;
    int reserved;

};

struct vmbusDevice *vmbusNewDevice(struct vmbusDevice *dev);
struct device *vmbusProbe(enum deviceClass probeClass, int probeFlags, struct device *devlist);
int vmbusReadDrivers(char *filename);
void vmbusFreeDrivers(void);

#endif
